@@ -7,7 +7,7 @@
 /* at Tue Jan 19 04:14:07 2038
  */
 /* Compiler settings for leechrpc.idl:
-    Oicf, W1, Zp8, env=Win64 (32b run), target_arch=AMD64 8.01.0626 
+    Oicf, W1, Zp8, env=Win64 (32b run), target_arch=ARM64 8.01.0626 
     protocol : all , ms_ext, c_ext, robust
     error checks: allocation ref bounds_check enum stub_data 
     VC __declspec() decoration level: 
@@ -16,7 +16,7 @@
 */
 /* @@MIDL_FILE_HEADING(  ) */
 
-#if defined(_M_AMD64)
+#if defined(_M_ARM64)
 
 
 #if _MSC_VER >= 1200
@@ -32,7 +32,7 @@
 #include "leechrpc_h.h"
 
 #define TYPE_FORMAT_STRING_SIZE   43                                
-#define PROC_FORMAT_STRING_SIZE   61                                
+#define PROC_FORMAT_STRING_SIZE   67                                
 #define EXPR_FORMAT_STRING_SIZE   1                                 
 #define TRANSMIT_AS_TABLE_SIZE    0            
 #define WIRE_MARSHAL_TABLE_SIZE   0            
@@ -177,7 +177,7 @@ error_status_t LeechRpc_ReservedSubmitCommand(
 }
 
 
-#if !defined(__RPC_WIN64__)
+#if !defined(__RPC_ARM64__)
 #error  Invalid build platform for this stub.
 #endif
 
@@ -192,52 +192,58 @@ static const leechrpc_MIDL_PROC_FORMAT_STRING leechrpc__MIDL_ProcFormatString =
 			0x48,		/* Old Flags:  */
 /*  2 */	NdrFcLong( 0x0 ),	/* 0 */
 /*  6 */	NdrFcShort( 0x0 ),	/* 0 */
-/*  8 */	NdrFcShort( 0x30 ),	/* X64 Stack size/offset = 48 */
+/*  8 */	NdrFcShort( 0x30 ),	/* ARM64 Stack size/offset = 48 */
 /* 10 */	0x32,		/* FC_BIND_PRIMITIVE */
 			0x0,		/* 0 */
-/* 12 */	NdrFcShort( 0x0 ),	/* X64 Stack size/offset = 0 */
+/* 12 */	NdrFcShort( 0x0 ),	/* ARM64 Stack size/offset = 0 */
 /* 14 */	NdrFcShort( 0x8 ),	/* 8 */
 /* 16 */	NdrFcShort( 0x24 ),	/* 36 */
 /* 18 */	0x47,		/* Oi2 Flags:  srv must size, clt must size, has return, has ext, */
 			0x5,		/* 5 */
-/* 20 */	0xa,		/* 10 */
+/* 20 */	0x10,		/* 16 */
 			0x7,		/* Ext Flags:  new corr desc, clt corr check, srv corr check, */
 /* 22 */	NdrFcShort( 0x1 ),	/* 1 */
 /* 24 */	NdrFcShort( 0x1 ),	/* 1 */
 /* 26 */	NdrFcShort( 0x0 ),	/* 0 */
-/* 28 */	NdrFcShort( 0x0 ),	/* 0 */
+/* 28 */	NdrFcShort( 0x5 ),	/* 5 */
+/* 30 */	0x5,		/* 5 */
+			0x80,		/* 128 */
+/* 32 */	0x81,		/* 129 */
+			0x82,		/* 130 */
+/* 34 */	0x83,		/* 131 */
+			0x84,		/* 132 */
 
 	/* Parameter cbIn */
 
-/* 30 */	NdrFcShort( 0x48 ),	/* Flags:  in, base type, */
-/* 32 */	NdrFcShort( 0x8 ),	/* X64 Stack size/offset = 8 */
-/* 34 */	0x8,		/* FC_LONG */
+/* 36 */	NdrFcShort( 0x48 ),	/* Flags:  in, base type, */
+/* 38 */	NdrFcShort( 0x8 ),	/* ARM64 Stack size/offset = 8 */
+/* 40 */	0x8,		/* FC_LONG */
 			0x0,		/* 0 */
 
 	/* Parameter pbIn */
 
-/* 36 */	NdrFcShort( 0x10b ),	/* Flags:  must size, must free, in, simple ref, */
-/* 38 */	NdrFcShort( 0x10 ),	/* X64 Stack size/offset = 16 */
-/* 40 */	NdrFcShort( 0x6 ),	/* Type Offset=6 */
+/* 42 */	NdrFcShort( 0x10b ),	/* Flags:  must size, must free, in, simple ref, */
+/* 44 */	NdrFcShort( 0x10 ),	/* ARM64 Stack size/offset = 16 */
+/* 46 */	NdrFcShort( 0x6 ),	/* Type Offset=6 */
 
 	/* Parameter pcbOut */
 
-/* 42 */	NdrFcShort( 0x2150 ),	/* Flags:  out, base type, simple ref, srv alloc size=8 */
-/* 44 */	NdrFcShort( 0x18 ),	/* X64 Stack size/offset = 24 */
-/* 46 */	0x8,		/* FC_LONG */
+/* 48 */	NdrFcShort( 0x2150 ),	/* Flags:  out, base type, simple ref, srv alloc size=8 */
+/* 50 */	NdrFcShort( 0x18 ),	/* ARM64 Stack size/offset = 24 */
+/* 52 */	0x8,		/* FC_LONG */
 			0x0,		/* 0 */
 
 	/* Parameter ppbOut */
 
-/* 48 */	NdrFcShort( 0x2013 ),	/* Flags:  must size, must free, out, srv alloc size=8 */
-/* 50 */	NdrFcShort( 0x20 ),	/* X64 Stack size/offset = 32 */
-/* 52 */	NdrFcShort( 0x16 ),	/* Type Offset=22 */
+/* 54 */	NdrFcShort( 0x2013 ),	/* Flags:  must size, must free, out, srv alloc size=8 */
+/* 56 */	NdrFcShort( 0x20 ),	/* ARM64 Stack size/offset = 32 */
+/* 58 */	NdrFcShort( 0x16 ),	/* Type Offset=22 */
 
 	/* Return value */
 
-/* 54 */	NdrFcShort( 0x70 ),	/* Flags:  out, return, base type, */
-/* 56 */	NdrFcShort( 0x28 ),	/* X64 Stack size/offset = 40 */
-/* 58 */	0x10,		/* FC_ERROR_STATUS_T */
+/* 60 */	NdrFcShort( 0x70 ),	/* Flags:  out, return, base type, */
+/* 62 */	NdrFcShort( 0x28 ),	/* ARM64 Stack size/offset = 40 */
+/* 64 */	0x10,		/* FC_ERROR_STATUS_T */
 			0x0,		/* 0 */
 
 			0x0
@@ -258,7 +264,7 @@ static const leechrpc_MIDL_TYPE_FORMAT_STRING leechrpc__MIDL_TypeFormatString =
 /*  8 */	NdrFcShort( 0x1 ),	/* 1 */
 /* 10 */	0x28,		/* Corr desc:  parameter, FC_LONG */
 			0x0,		/*  */
-/* 12 */	NdrFcShort( 0x8 ),	/* X64 Stack size/offset = 8 */
+/* 12 */	NdrFcShort( 0x8 ),	/* ARM64 Stack size/offset = 8 */
 /* 14 */	NdrFcShort( 0x1 ),	/* Corr flags:  early, */
 /* 16 */	0x1,		/* FC_BYTE */
 			0x5b,		/* FC_END */
@@ -278,7 +284,7 @@ static const leechrpc_MIDL_TYPE_FORMAT_STRING leechrpc__MIDL_TypeFormatString =
 /* 32 */	NdrFcShort( 0x1 ),	/* 1 */
 /* 34 */	0x28,		/* Corr desc:  parameter, FC_LONG */
 			0x54,		/* FC_DEREFERENCE */
-/* 36 */	NdrFcShort( 0x18 ),	/* X64 Stack size/offset = 24 */
+/* 36 */	NdrFcShort( 0x18 ),	/* ARM64 Stack size/offset = 24 */
 /* 38 */	NdrFcShort( 0x1 ),	/* Corr flags:  early, */
 /* 40 */	0x1,		/* FC_BYTE */
 			0x5b,		/* FC_END */
@@ -294,7 +300,7 @@ static const unsigned short LeechRpc_FormatStringOffsetTable[] =
 
 
 
-#endif /* defined(_M_AMD64)*/
+#endif /* defined(_M_ARM64) */
 
 
 
@@ -305,7 +311,7 @@ static const unsigned short LeechRpc_FormatStringOffsetTable[] =
 /* at Tue Jan 19 04:14:07 2038
  */
 /* Compiler settings for leechrpc.idl:
-    Oicf, W1, Zp8, env=Win64 (32b run), target_arch=AMD64 8.01.0626 
+    Oicf, W1, Zp8, env=Win64 (32b run), target_arch=ARM64 8.01.0626 
     protocol : all , ms_ext, c_ext, robust
     error checks: allocation ref bounds_check enum stub_data 
     VC __declspec() decoration level: 
@@ -314,12 +320,12 @@ static const unsigned short LeechRpc_FormatStringOffsetTable[] =
 */
 /* @@MIDL_FILE_HEADING(  ) */
 
-#if defined(_M_AMD64)
+#if defined(_M_ARM64)
 
 
 
 
-#if !defined(__RPC_WIN64__)
+#if !defined(__RPC_ARM64__)
 #error  Invalid build platform for this stub.
 #endif
 
@@ -377,11 +383,6 @@ struct _NDR64_POINTER_FORMAT
 __midl_frag8_t;
 extern const __midl_frag8_t __midl_frag8;
 
-typedef 
-NDR64_FORMAT_CHAR
-__midl_frag7_t;
-extern const __midl_frag7_t __midl_frag7;
-
 typedef 
 struct 
 {
@@ -405,11 +406,6 @@ struct _NDR64_POINTER_FORMAT
 __midl_frag4_t;
 extern const __midl_frag4_t __midl_frag4;
 
-typedef 
-NDR64_FORMAT_CHAR
-__midl_frag3_t;
-extern const __midl_frag3_t __midl_frag3;
-
 typedef 
 struct 
 {
@@ -420,6 +416,12 @@ struct
     struct _NDR64_PARAM_FORMAT frag5;
     struct _NDR64_PARAM_FORMAT frag6;
     struct _NDR64_PARAM_FORMAT frag7;
+    struct /* ARM Parameter Layout */
+    {
+        NDR64_UINT16 frag1;
+        NDR64_UINT8 frag2;
+        NDR64_UINT8 frag3[ 5 ];
+    } frag8;
 }
 __midl_frag2_t;
 extern const __midl_frag2_t __midl_frag2;
@@ -514,9 +516,6 @@ static const __midl_frag8_t __midl_frag8 =
     &__midl_frag9
 };
 
-static const __midl_frag7_t __midl_frag7 =
-0x2    /* FC64_INT8 */;
-
 static const __midl_frag6_t __midl_frag6 =
 { 
 /*  */
@@ -555,7 +554,7 @@ static const __midl_frag5_t __midl_frag5 =
     { 
     /* struct _NDR64_ARRAY_ELEMENT_INFO */
         (NDR64_UINT32) 1 /* 0x1 */,
-        &__midl_frag7
+        &__midl_frag14
     }
 };
 
@@ -568,15 +567,12 @@ static const __midl_frag4_t __midl_frag4 =
     &__midl_frag5
 };
 
-static const __midl_frag3_t __midl_frag3 =
-0x5    /* FC64_INT32 */;
-
 static const __midl_frag2_t __midl_frag2 =
 { 
 /* LeechRpc_ReservedSubmitCommand */
     { 
     /* LeechRpc_ReservedSubmitCommand */      /* procedure LeechRpc_ReservedSubmitCommand */
-        (NDR64_UINT32) 23986240 /* 0x16e0040 */,    /* explicit handle */ /* IsIntrepreted, ServerMustSize, ClientMustSize, HasReturn, ServerCorrelation, ClientCorrelation, HasExtensions */
+        (NDR64_UINT32) 91095104 /* 0x56e0040 */,    /* explicit handle */ /* IsIntrepreted, ServerMustSize, ClientMustSize, HasReturn, ServerCorrelation, ClientCorrelation, HasExtensions, HasArmParamLayout */
         (NDR64_UINT32) 48 /* 0x30 */ ,  /* Stack size */
         (NDR64_UINT32) 8 /* 0x8 */,
         (NDR64_UINT32) 40 /* 0x28 */,
@@ -599,7 +595,7 @@ static const __midl_frag2_t __midl_frag2 =
     },
     { 
     /* cbIn */      /* parameter cbIn */
-        &__midl_frag3,
+        &__midl_frag9,
         { 
         /* cbIn */
             0,
@@ -716,6 +712,19 @@ static const __midl_frag2_t __midl_frag2 =
         },    /* [out], IsReturn, Basetype, ByValue */
         (NDR64_UINT16) 0 /* 0x0 */,
         40 /* 0x28 */,   /* Stack offset */
+    },
+    { 
+    /* LeechRpc_ReservedSubmitCommand */      /* ARM register placement data */
+        (NDR64_UINT16) 5 /* 0x5 */ ,  /* Number of Entries */
+        (NDR64_UINT8) 5 /* 0x5 */ ,  /* Slots Used */
+        { 
+        /* LeechRpc_ReservedSubmitCommand */      /* Placement data octets */
+            (NDR64_UINT8) 0x80, 
+            (NDR64_UINT8) 0x81, 
+            (NDR64_UINT8) 0x82, 
+            (NDR64_UINT8) 0x83, 
+            (NDR64_UINT8) 0x84
+        }
     }
 };
 
@@ -796,5 +805,5 @@ static const MIDL_STUBLESS_PROXY_INFO LeechRpc_ProxyInfo =
 #endif
 
 
-#endif /* defined(_M_AMD64)*/
+#endif /* defined(_M_ARM64) */
 
